====================
 Usage instructions
====================

Using the site
==============

Adding content
==============

A *PipeBook* is split into two parts. The :ref:`Pipeline` section
contains automatically created tables and plots created for
the pipeline. The :ref:`Analysis` section contains observations 
specific to a current run.
